""" boris.utils

    The boris.utils module provides commonly used utility methods
"""

from ._io import save_embeddings
from ._io import load_embeddings
from ._io import load_embeddings_as_dict
from ._2d_embeddings import fit_pca
